%define revdns		org.shotcut.Shotcut
%define mltmajor	7

Name:           shotcut
Version:        21.12.24
Release:        %mkrel 4
Summary:        A free, open source, cross-platform video editor
Group:          Video/Editors and Converters
# The entire source code is GPLv3+ except mvcp/ which is LGPLv2+
License:        GPLv3+ and LGPLv2+
URL:            https://www.shotcut.org
Source0:        https://github.com/mltframework/shotcut/archive/v%{version}/%{name}-%{version}.tar.gz
# Disable update checks, won't work on packaged version
Patch0:         shotcut-18.05.08-mga-disable-upgrade-check.patch

BuildRequires:  pkgconfig(mlt++-%{mltmajor})
BuildRequires:  pkgconfig(mlt-framework-%{mltmajor})
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.9.1
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5QuickWidgets)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  qttools5
# (akien) Not packaged yet in Mageia
#BuildRequires:  webvfx-devel

# Apparently dependencies are dlopen()'ed
# To be confirmed, but for now requiring to avoid issues
Requires:       frei0r
Requires:       gstreamer1.0-plugins-bad
Requires:       gstreamer1.0-plugins-good
Requires:       gstreamer1.0-plugins-ugly
Requires:       ladspa
Requires:       lame
Requires:       ffmpeg
Requires:       mlt
Requires:       qtquickcontrols5
Requires:       qtquickcontrols2
Requires:       qtgraphicaleffects5
Requires:       qtmultimedia5
Requires:       qtdeclarative5

%description
Shotcut is a free and open-source cross-platform video editing application for
Windows, OS X, and Linux.

Shotcut supports many video, audio, and image formats via FFmpeg and screen,
webcam, and audio capture. It uses a time-line for non-linear video editing of
multiple tracks that may be composed of various file formats. Scrubbing and
transport control are assisted by OpenGL GPU-based processing and a number of
video and audio filters are available.

%prep
%autosetup -p1

# Postmortem debugging tools for MinGW.
rm -rf drmingw

%build
%qmake_qt5 \
  PREFIX=%{_prefix} \
  SHOTCUT_VERSION="%{version}-%{release}"
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# List language files
for path in %{buildroot}%{_datadir}/%{name}/translations/*; do
  file=$(basename $path)
  lang=$(echo $file | sed -e "s/shotcut_\([A-Za-z_]*\)\.qm/\1/")
  path=$(echo $path | sed -e "s|%{buildroot}||")
  echo "%lang($lang) $path" >> "%{name}.lang"
done

%files -f %{name}.lang
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{revdns}.desktop
%{_datadir}/metainfo/%{revdns}.metainfo.xml
%{_datadir}/mime/packages/%{revdns}.xml
%{_iconsdir}/hicolor/*/apps/%{revdns}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Thu Mar 23 2023 daviddavid <daviddavid> 21.12.24-4.mga9
+ Revision: 1950206
- drop no more needed by the project Qt5WebKit build dependency

* Wed Apr 06 2022 umeabot <umeabot> 21.12.24-3.mga9
+ Revision: 1845869
- Mageia 9 Mass Rebuild

* Sat Jan 29 2022 neoclust <neoclust> 21.12.24-2.mga9
+ Revision: 1770183
- Rebuild against new libmlt++

* Mon Dec 27 2021 ghibo <ghibo> 21.12.24-1.mga9
+ Revision: 1764303
- Update to release 21.12.24 to keep in par with mlt
+ daviddavid <daviddavid>
- new version: 21.03.13

* Fri Feb 26 2021 daviddavid <daviddavid> 21.02.15-1.mga9
+ Revision: 1692046
- new version: 21.02.15

* Thu Dec 17 2020 umeabot <umeabot> 20.10.31-2.mga8
+ Revision: 1659846
- Rebuild for new Qt5

* Sun Nov 08 2020 daviddavid <daviddavid> 20.10.31-1.mga8
+ Revision: 1643819
- new version: 20.10.31

* Mon Sep 28 2020 daviddavid <daviddavid> 20.09.27-1.mga8
+ Revision: 1630938
- new version: 20.09.27

* Wed Sep 02 2020 daviddavid <daviddavid> 20.09.01-1.mga8
+ Revision: 1620879
- new version: 20.09.01

* Sun Jul 12 2020 daviddavid <daviddavid> 20.07.11-1.mga8
+ Revision: 1605472
- new version: 20.07.11

* Mon Jun 29 2020 daviddavid <daviddavid> 20.06.28-1.mga8
+ Revision: 1600321
- new version: 20.06.28

* Mon Apr 06 2020 daviddavid <daviddavid> 20.04.05-1.mga8
+ Revision: 1565047
- new version: 20.04.05

* Tue Mar 24 2020 daviddavid <daviddavid> 20.02.17-2.mga8
+ Revision: 1559440
- add missing dependency on QtQuick 2 (qtquickcontrols2)

* Tue Mar 24 2020 daviddavid <daviddavid> 20.02.17-1.mga8
+ Revision: 1559408
- new version: 20.02.17
- add missing dependency on qtdeclarative5

* Tue Feb 18 2020 umeabot <umeabot> 19.10.20-2.mga8
+ Revision: 1538308
- Mageia 8 Mass Rebuild

* Mon Nov 18 2019 zezinho <zezinho> 19.10.20-1.mga8
+ Revision: 1461659
- new version
+ akien <akien>
- Rebuild to ensure higher NEVR as mga7 update candidate (mga#25513)

* Wed Oct 02 2019 akien <akien> 19.09.14-1.mga8
+ Revision: 1448847
- Version 19.04.14

* Sat Aug 03 2019 zezinho <zezinho> 19.07.15-1.mga8
+ Revision: 1427171
- new version 19.07

* Tue Apr 02 2019 umeabot <umeabot> 18.12.23-2.mga7
+ Revision: 1384795
- Qt5 Rebuild

* Sun Jan 13 2019 akien <akien> 18.12.23-1.mga7
+ Revision: 1355867
- Version 18.12.23

* Sun Sep 23 2018 umeabot <umeabot> 18.05.08-2.mga7
+ Revision: 1301018
- Mageia 7 Mass Rebuild

* Tue May 29 2018 akien <akien> 18.05.08-1.mga7
+ Revision: 1232937
- Add RPM group
- Simplify packaging
  o Remove lang subpackages, properly use .lang file
  o Remove doc subpackage
  o Disable update checks instead of trying to hack it away
  o Reorder BuildRequires
- import shortcut-18.05.08-1.fc29.src.rpm from RPM Fusion


* Sat May 12 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.05.08-1
- Update to 18.05.08

* Fri Apr 27 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.03.06-1
- Update to 18.03.06

* Sun Mar 04 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.03-1
- Update to 18.03

* Thu Mar 01 2018 RPM Fusion Release Engineering <leigh123linux@googlemail.com> - 18.01-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 08 2018 Martin Gansser <martinkg@fedoraproject.org> - 18.01-1
- Update to 18.01

* Sat Dec 09 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.12-2
- Rebuild

* Fri Dec 08 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.12-1
- Update to 17.12

* Sat Nov 04 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.11-1
- Update to 17.11

* Sat Oct 14 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.10-1
- Update to 17.10
- pkgconfig(Qt5Core) >= 5.9.2 is required
- Add LGPLv2+ to license and comment
- Build Doxygen html documentation
- Add BR doxygen

* Fri Sep 08 2017 Martin Gansser <martinkg@fedoraproject.org> - 17.09-1
- Initial build
